import { QueryFunction } from 'mysql';
export interface MigrationConnection {
    query: QueryFunction;
    end(callback?: (err: Error | null) => void): void;
}
export interface MigrationConfig {
    conn: MigrationConnection;
    tableName: string;
    dir: string;
    silent?: boolean;
    strictOrder?: boolean;
    numOrder?: boolean;
}
export interface MigrationScript {
    version: number;
    fileName: string;
    upgrade?(queryFn?: (query: string, value: any[]) => Promise<Array<any>>): any | Promise<any>;
    downgrade?(queryFn?: (query: string, value: any[]) => Promise<Array<any>>): any | Promise<any>;
}
export declare class Migration {
    private config;
    private scripts;
    private maxVersion;
    private isInit;
    private strictOrder;
    private numOrder;
    constructor(config: MigrationConfig);
    initialize(): Promise<void>;
    up(steps?: number): Promise<void>;
    down(steps?: number): Promise<void>;
    reset(): Promise<void>;
    getLastVersion(): Promise<{
        version: number;
        fileName: string;
    }>;
    getLoadedScripts(sortDirection?: string): Promise<{
        version: number;
        fileName: string;
    }[]>;
    destroy(): Promise<void>;
    private loadScripts;
    private getNextUpgradeScript;
    private getNextDowngradeScript;
    private initMigrationTable;
    private saveVersion;
    private deleteVersion;
    private query;
    private sortFiles;
    private writeLog;
}
